import { Injectable } from '@nestjs/common';
import { IndexItemManager } from './managers/index-item.manager';
import { ItemReadService } from '../../data/services/item-read.service';
import { ItemEntity } from '../entities/item.entity';
import { PaginationResponse } from 'src/core/response/domain/ok-response.interface';
import { BaseReadOrchestrator } from 'src/core/modules/domain/usecase/orchestrators/base-read.orchestrator';
import { DetailItemManager } from './managers/detail-item.manager';
import { TABLE_NAME } from 'src/core/strings/constants/table.constants';

@Injectable()
export class ItemReadOrchestrator extends BaseReadOrchestrator<ItemEntity> {
  constructor(
    private indexManager: IndexItemManager,
    private detailManager: DetailItemManager,
    private serviceData: ItemReadService,
  ) {
    super();
  }

  async index(params): Promise<PaginationResponse<ItemEntity>> {
    this.indexManager.setFilterParam(params);
    this.indexManager.setService(this.serviceData, TABLE_NAME.ITEM);
    await this.indexManager.execute();
    return this.indexManager.getResult();
  }

  async detail(dataId: string): Promise<ItemEntity> {
    this.detailManager.setData(dataId);
    this.detailManager.setService(this.serviceData, TABLE_NAME.ITEM);
    await this.detailManager.execute();
    return this.detailManager.getResult();
  }
}
